==> dde-dock_5.4.10.orig.tar.xz: dde-dock-5.4.10/translations/dde-dock_zh_HK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_HK" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>插件%1和系統版本不兼容。</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>藍牙設置</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>關閉</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>開啟</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>藍牙設置</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>已連接%1</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>正在連接...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>藍牙</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>藍牙關閉</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>藍牙</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>添加鍵盤佈局</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>時間</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12小時制</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24小時制</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>時間設置</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>啟用網絡</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>關閉網絡</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>網絡設置</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>您確定要清空回收站裏的%1項內容嗎？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>這個動作不可復原</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>未知的設備</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>容量未知</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>磁碟</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>打開</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>卸載全部</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>啟動器</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation>退出安全模式</translation>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation>任務欄安全模式</translation>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation>任務欄已進入安全模式，退出安全模式後即可正常顯示</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>時尚模式</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>高效模式</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>頂</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>底</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>一直顯示</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>一直隱藏</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>智能隱藏</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>模式</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>位置</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>狀態</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>外掛</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>多任務視圖</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>移除駐留</translation>
    </message>
</context>
<context>
    <name>NetworkItem</name>
    <message>
        <source>Disable wired connection</source>
        <translation>關閉有線網絡</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>啟用有線網絡</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>關閉無線網絡</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>啟用無線網絡</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>關閉網絡</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>啟用網絡</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>網絡設置</translation>
    </message>
    <message>
        <source>Device disabled</source>
        <translation>設備已禁用</translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation>無線連接：%1</translation>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>有線連接：%1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>未連接</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>連接中</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>已連接網絡但無法訪問互聯網</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>未插入網線</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>無線網絡</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>有線網絡</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>連接失敗</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>網絡</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>有線網絡</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>有線網絡 %1</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>螢幕鍵盤</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設置</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>電源</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>電源設置</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>電量%1，剩餘%2分鐘</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>電量%1，剩餘%2小時%3分鐘</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>正在充電%1，還需%2分鐘</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>正在充電%1，還需%2小時%3分鐘</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation>已充滿</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>電量 %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>正在充電%1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>電量%1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>電量%1，已充滿</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>顯示桌面</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>移除駐留</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>電源</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>關機</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>待機</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>鎖定</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>註銷</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>切換帳戶</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>電源設置</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重新啟動</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>裝置</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>取消靜音</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>靜音</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>音量設置</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>當前音量 %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>聲音</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>回收站</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>回收站 - %1個文件</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>回收站 - %1個文件</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>打開</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>清空</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <source>System Tray</source>
        <translation>系統托盤</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>無線網絡</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>無線網絡%1</translation>
    </message>
</context>
</TS>

==> dde-dock_5.5.53.orig.tar.xz: dde-dock-5.5.53/translations/dde-dock_zh_HK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_HK">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>插件%1和系統版本不兼容。</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation>飛行模式</translation>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>飛行模式開啟</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>關閉</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>開啟</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation>飛行模式設置</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>飛行模式關閉</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>飛行模式</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>藍牙設置</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>關閉</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>開啟</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>藍牙設置</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>已連接%1</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>正在連接...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>藍牙</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>藍牙關閉</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>藍牙</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>添加鍵盤佈局</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>時間</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12小時制</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24小時制</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>時間設置</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>您確定要清空回收站裏的%1項內容嗎？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>這個動作不可復原</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>未知的設備</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>容量未知</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>磁碟</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>打開</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>卸載全部</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>啟動器</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation>退出安全模式</translation>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation>任務欄安全模式</translation>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation>任務欄已進入安全模式，退出安全模式後即可正常顯示</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>時尚模式</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>高效模式</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>頂</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>底</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>一直顯示</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>一直隱藏</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>智能隱藏</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>模式</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>位置</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>狀態</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation>任務欄設置</translation>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>多屏顯示設置</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>插件區域</translation>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>選擇顯示在任務欄插件區域的圖標</translation>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation>時尚模式</translation>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation>高效模式</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>模式</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>頂</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>底</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>位置</translation>
    </message>
    <message>
        <source>Keep shown</source>
        <translation>一直顯示</translation>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>一直隱藏</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>智能隱藏</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>狀態</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>小</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>大</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation>任務欄位置</translation>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>跟隨鼠標位置顯示</translation>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation>僅主屏顯示</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>多任務視圖</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>移除駐留</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>螢幕鍵盤</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設置</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>電源</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>電源設置</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>電量%1，剩餘%2分鐘</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>電量%1，剩餘%2小時%3分鐘</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>正在充電%1，還需%2分鐘</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>正在充電%1，還需%2小時%3分鐘</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>電量 %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>正在充電%1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>電量%1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>電量%1，已充滿</translation>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation>任務欄</translation>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>顯示桌面</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>移除駐留</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>電源</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>關機</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>待機</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>鎖定</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>註銷</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>切換帳戶</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>電源設置</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重新啟動</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>裝置</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>取消靜音</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>靜音</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>音量設置</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>當前音量 %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>聲音</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>回收站</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>回收站 - %1個文件</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>回收站 - %1個文件</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>移動到回收站</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>打開</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>清空</translation>
    </message>
</context>
</TS>
